@@ -31,12 +31,14 @@ def authenticate():
 @argh.arg('-v', '--value', nargs='+', type=str)
 def lookup(project: "ATLAS Subproject" = 'S',
            lookupKey: "Key that corresponds to VALUE" = 'serialNumber',
-           value: "Values to look up (can be a list)" = [],
+           value: "Values to look up (can be a list)" = None,
            componentType: "Type of component" = 'BT',
            returnResults: "Return lookup results (useful if not used from CLI)" = False,
            printJSON: "PrettyPrint the component JSON" = False):
     "Look up a component or list of components in the DB."
     try:
+        if value is None:
+            value = []
         client = itkdb.Client()
         components = client.get('listComponents', json={
                                 'project': project, "componentType": componentType})
@@ -54,10 +56,11 @@ def lookup(project: "ATLAS Subproject" = 'S',
                 logger.info(
                     f"Found {lookupKey} = {comp[lookupKey]}: {comp['code']}")
                 results[str(comp[lookupKey])] = comp
+        print("I'm here...")
         if printJSON:
             for k in results:
                 print(json.dumps(results[k], indent=1))
-        if returnResults:
+        if returnResults or __name__ != '__main__':
             return results
     except:
         logger.error("Error while trying to get connection to DB")
@@ -135,7 +138,7 @@ def tests(componentType: "Type of component" = "BT",
                 print(test['code'], ":", test['name'])
                 for p in test['parameters']:
                     print("  ", p['code'], ":", p['name'])
-        if returnResults:
+        if returnResults or __name__ != '__main__':
             return result
     except:
         logger.error("Error while trying to get connection to DB")
@@ -144,7 +147,7 @@ def tests(componentType: "Type of component" = "BT",
 
 
 def stage(lookupValue: "Value to look up (must be unique in the DB!)",
-          stage: "Production stage to set" = "",
+          stage: "Production stage to set",
           project: "ATLAS Subproject" = 'S',
           lookupKey: "Key that corresponds to VALUE" = 'serialNumber',
           componentType: "Type of component" = 'BT',
@@ -181,7 +184,7 @@ def stage(lookupValue: "Value to look up (must be unique in the DB!)",
             f"DB error, is {stage} a valid stage for {componentType}?")
 
 
-def skeleton(test: "Type of test" = "",
+def skeleton(test: "Type of test",
              componentType: "Type of component" = "BT",
              project: "ATLAS Subproject" = 'S',
              returnResults: "Return available tests (useful if not used from CLI)" = False):
@@ -210,7 +213,7 @@ def skeleton(test: "Type of test" = "",
     for v in allTests[test]["parameters"]:
         skeleton["results"][v["code"]] = None
 
-    if returnResults:
+    if returnResults or __name__ != '__main__':
         return skeleton
     else:
         print(json.dumps(allTests[test], indent=1))
@@ -236,11 +239,34 @@ def upload(result: "Results from the test (path to .json file or dict)"):
     except:
         logger.error(f"Unable to upload result to DB, is the format correct?")
 
+def testruns(cid: "Component ID",
+             returnResults: "Return lookup results (useful if not used from CLI)" = False,
+             printJSON: "PrettyPrint the component JSON" = False):
+    "Look up all test results associated with a component ID."
+    try:
+        logger.info(f"Looking up tests in CID = {cid}")
+        client = itkdb.Client()
+        runs = client.get('listTestRunsByComponent', json={'component' : cid})
+        results = {}
+        for i, testres in enumerate(runs):
+            logger.info(f"Found {testres['testType']['name']} with ID = {testres['id']}")
+            results[testres['id']] = testres
+        if printJSON:
+            for k in results:
+                print(json.dumps(results[k], indent=1))
+        if returnResults or __name__ != '__main__':
+            return results
+    except:
+        logger.error("Error while trying to get connection to DB")
+        logger.info(
+            "Are environment variables ITKDB_ACCESS_CODE1 and ITKDB_ACCESS_CODE2 set?")
+
+
 
 def main():
     parser = argh.ArghParser()
     parser.add_commands([authenticate, register, lookup,
-                        attach, tests, stage, skeleton, upload])
+                        attach, tests, stage, skeleton, upload, testruns])
     parser.dispatch()
 
 
